PALM-meteo: palmmeteo.config.ConfigError Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.config.ConfigError Class Reference
Inheritance diagram for palmmeteo.config.ConfigError:
[legend]
Collaboration diagram for palmmeteo.config.ConfigError:
[legend]

## Public Member Functions
def | __init__ (self, desc, section=None, key=None)
def | __str__ (self)

## Public Attributes
| desc
| section
| key
| msg

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.config.ConfigError.__init__ | ( |  | self,
|  |  | desc,
|  |  | section = `None`,
|  |  | key = `None`
| ) |  |

## Member Function Documentation

## ◆ __str__()

def palmmeteo.config.ConfigError.__str__ | ( |  | self | ) |

## Member Data Documentation

## ◆ desc

palmmeteo.config.ConfigError.desc

## ◆ key

palmmeteo.config.ConfigError.key

## ◆ msg

palmmeteo.config.ConfigError.msg

## ◆ section

palmmeteo.config.ConfigError.section

The documentation for this class was generated from the following file:

- palmmeteo/config.py